## Copyright (C) 2015 Oscar Monerris Belda
## 
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {Function File} {@var{xwrap} =} wrapTo2Pi (@var{x})
##
## Wraps x into the 0 to 2pi interval
##
## @var{x}: angle in radians (single value or vector)
##
## @example
## pi/2 = wrapTo2Pi (5*pi/2)
## @end example
##
## @seealso{wrapTo180, wrapTo360, wraptoPi}
## @end deftypefn

function xwrap = wrapTo2Pi (x)
  xwrap = mod (x, 2 * pi);
endfunction

%!test
%! x = -9:0.1:9;
%! xw = wrapTo2Pi (x);
%! assert (sin (x), sin (xw), 8 * eps)
%! assert (cos (x), cos (xw), 8 * eps)
%! assert (! any (xw < 0))
%! assert (! any (xw > 2 * pi))
