## Copyright (C) 2015 Oscar Monerris Belda
## 
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {Function File} {@var{xwrap} =} wrapToPi (@var{x})
##
## Wraps x into the -pi to pi interval
##
## @var{x}: angle in radians (single value or vector)
##
## @example
## -pi/2 = wrapToPi (3*pi/2)
## @end example
##
## @seealso{wrapTo180, wrapTo360, wrapto2Pi}
## @end deftypefn

function xwrap = wrapToPi (x)
  xwrap = mod (x + pi, 2 * pi) - pi;
endfunction

%!test
%! x = -9:0.1:9;
%! xw = wrapToPi (x);
%! assert (sin (x), sin (xw), 8 * eps)
%! assert (cos (x), cos (xw), 8 * eps)
%! assert (! any (xw < -pi))
%! assert (! any (xw > pi))
